@@ -77,7 +77,7 @@ void KCalcButton::slotSetMode(ButtonModeFlags mode, bool flag)
 
     if (flag) { // if the specified mode is to be set (i.e. flag = true)
         new_mode = ButtonModeFlags(mode_flags_ | mode);
-    } else if (mode_flags_ && mode) { // if the specified mode is to be cleared (i.e. flag = false)
+    } else if (mode_flags_ & mode) { // if the specified mode is to be cleared (i.e. flag = false)
         new_mode = ButtonModeFlags(mode_flags_ - mode);
     } else {
         return; // nothing to do
@@ -188,7 +188,7 @@ void KCalcButton::calcSizeHint()
 {
     int margin = style()->pixelMetric(QStyle::PM_ButtonMargin, nullptr, this);
 
-    // want narrow margin than normal
+    // want narrower margin than normal
     margin = qMax(margin / 2, 3);
 
     // simply use font size of a single letter
